#include "stm32f05xxx.h"
#include "spi.h"

/* SPI interface is SPI1 routed as follows:
	PA4	SPI1_NSS		(AF0)
	PA5	SPI1_SCK		(AF0)
	PA6	SPI1_MISO		(AF0)
	PA7	SPI1_MOSI		(AF0)
*/
extern short HandleSPICommand(short cmd, short param);
void initSPI()
{
	// MUST turn on GPIOA 
	SET_BIT(RCC_AHBENR,BIT17);
	// configure the spi pins
	SET_BIT(GPIOA_MODER,BIT15+BIT13+BIT11+BIT9);
	CLEAR_BIT(GPIOA_MODER,BIT14+BIT12+BIT10+BIT8);
	// assuming AFRL and AFRH are at zero from reset	
	// Turn on SPI1
	SET_BIT(RCC_APB2ENR,BIT12);
	// Take SPI1 out of reset
	CLEAR_BIT(RCC_APB2RSTR,BIT12);
	// Set the baud rate (500kHz - assumes 8MHz pclk) not sure this has any effect in slave mode
	SET_BIT(SPI1_CR1,BIT4);
	// Set the word size (8 bits)
	SET_BIT(SPI1_CR2,(15 << 8));	
	// Enable RX interrupts
	SET_BIT(SPI1_CR2,BIT6);	
	// Enable error handling interrupt
	SET_BIT(SPI1_CR2,BIT5);
	// enable spi
	SET_BIT(SPI1_CR1,BIT6);	
	// Enable SPI1 interrupts in NVIC
	ISER |= BIT25;
	// enable global interrupts.	
	enable_interrupts();
	SPI1_DR = 0;
}
void isr_spi1(void)
{
// interrupt handler for spi1
	short cmd;
	short param;
	short output;
	short rword;
	static short count=0;
	if (SPI1_SR & BIT0) 
	{	
		// rxne 
		rword=SPI1_DR;
// assuming that the sender sent over a 16 bit number in two 8 bit chunks
// rword should contain a little this 16 bit word with bytes reversed.
		param = (rword & 0xff);
		cmd =(rword >> 8);		
		rword=HandleSPICommand(cmd,param);
		output=((rword & 0xff) << 8) + (rword >>8);
		SPI1_DR=output;
	}
	
}
